@@ -1,24 +1,26 @@
 debug <- local({
   status <- NA
-  
+
   function(action = NA) {
-    if (is.na(status)) {     
+    if (is.na(status)) {
       t <- as.logical(Sys.getenv("R_STARTUP_DEBUG", NA))
       t <- getOption("startup.debug", t)
-      
+
       ## If neither env var nor option is specified, then
       ## look at command-line options
       if (is.na(t)) {
         args <- commandArgs()
-        if (any(c("-q", "--quiet", "--silent", "--slave") %in% args)) t <- FALSE
+        if (any(c("-q", "--quiet", "--silent", "--slave") %in% args)) {
+          t <- FALSE
+        }
         if ("--verbose" %in% args) t <- TRUE
       }
 
       t <- isTRUE(t)
-      
+
       status <<- t
     }
-    
+
     action <- as.logical(action)
     if (!is.na(action)) status <<- action
     status
@@ -51,3 +53,6 @@ timestamp <- local({
   }
 })
 
+notef <- function(..., quiet = FALSE) {
+  if (!quiet) message(sprintf(...))
+}
